@@ -101,9 +101,9 @@ bc_vm_jmp(void)
 	bc_file_flush(&vm->ferr, bc_flush_none);
 #endif // BC_DEBUG_CODE
 
-#ifndef NDEBUG
+#if BC_DEBUG
 	assert(vm->jmp_bufs.len - (size_t) vm->sig_pop);
-#endif // NDEBUG
+#endif // BC_DEBUG
 
 	if (vm->jmp_bufs.len == 0) abort();
 	if (vm->sig_pop) bc_vec_pop(&vm->jmp_bufs);
@@ -349,13 +349,13 @@ bc_vm_handleError(BcErr e)
 	BC_JMP;
 }
 #else // BC_ENABLE_LIBRARY
-#ifndef NDEBUG
+#if BC_DEBUG
 void
 bc_vm_handleError(BcErr e, const char* file, int fline, size_t line, ...)
-#else // NDEBUG
+#else // BC_DEBUG
 void
 bc_vm_handleError(BcErr e, size_t line, ...)
-#endif // NDEBUG
+#endif // BC_DEBUG
 {
 	BcStatus s;
 	va_list args;
@@ -423,9 +423,9 @@ bc_vm_handleError(BcErr e, size_t line, ...)
 		bc_file_putchar(&vm->ferr, bc_flush_none, '\n');
 	}
 
-#ifndef NDEBUG
+#if BC_DEBUG
 	bc_file_printf(&vm->ferr, "\n    %s:%d\n", file, fline);
-#endif // NDEBUG
+#endif // BC_DEBUG
 
 	bc_file_puts(&vm->ferr, bc_flush_none, "\n");
 
@@ -622,8 +622,12 @@ bc_vm_envLen(const char* var)
 	if (num)
 	{
 		// Parse it and clamp it if needed.
-		len = (size_t) atoi(lenv) - 1;
-		if (len == 1 || len >= UINT16_MAX) len = BC_NUM_PRINT_WIDTH;
+		len = (size_t) strtol(lenv, NULL, 10);
+		if (len != 0)
+		{
+			len -= 1;
+			if (len < 2 || len >= UINT16_MAX) len = BC_NUM_PRINT_WIDTH;
+		}
 	}
 	// Set the default.
 	else len = BC_NUM_PRINT_WIDTH;
@@ -643,14 +647,16 @@ bc_vm_shutdown(void)
 	if (vm->catalog != BC_VM_INVALID_CATALOG) catclose(vm->catalog);
 #endif // BC_ENABLE_NLS
 
+#if !BC_ENABLE_LIBRARY
 #if BC_ENABLE_HISTORY
 	// This must always run to ensure that the terminal is back to normal, i.e.,
 	// has raw mode disabled. But we should only do it if we did not have a bad
 	// terminal because history was not initialized if it is a bad terminal.
 	if (BC_TTY && !vm->history.badTerm) bc_history_free(&vm->history);
 #endif // BC_ENABLE_HISTORY
+#endif // !BC_ENABLE_LIBRARY
 
-#ifndef NDEBUG
+#if BC_DEBUG
 #if !BC_ENABLE_LIBRARY
 	bc_vec_free(&vm->env_args);
 	free(vm->env_args_buffer);
@@ -670,7 +676,7 @@ bc_vm_shutdown(void)
 #endif // !BC_ENABLE_LIBRARY
 
 	bc_vm_freeTemps();
-#endif // NDEBUG
+#endif // BC_DEBUG
 
 #if !BC_ENABLE_LIBRARY
 	// We always want to flush.
@@ -1242,12 +1248,12 @@ err:
 		goto restart;
 	}
 
-#ifndef NDEBUG
+#if BC_DEBUG
 	// Since these are tied to this function, free them here. We only free in
 	// debug mode because stdin is always the last thing read.
 	bc_vec_free(&vm->line_buf);
 	bc_vec_free(&vm->buffer);
-#endif // NDEBUG
+#endif // BC_DEBUG
 
 	BC_LONGJMP_CONT(vm);
 }
@@ -1767,17 +1773,17 @@ bc_vm_init(void)
 void
 bc_vm_atexit(void)
 {
-#ifndef NDEBUG
+#if BC_DEBUG
 #if BC_ENABLE_LIBRARY
 	BcVm* vm = bcl_getspecific();
 #endif // BC_ENABLE_LIBRARY
-#endif // NDEBUG
+#endif // BC_DEBUG
 
 	bc_vm_shutdown();
 
-#ifndef NDEBUG
+#if BC_DEBUG
 	bc_vec_free(&vm->jmp_bufs);
-#endif // NDEBUG
+#endif // BC_DEBUG
 }
 #else // BC_ENABLE_LIBRARY
 int
@@ -1788,9 +1794,9 @@ bc_vm_atexit(int status)
 
 	bc_vm_shutdown();
 
-#ifndef NDEBUG
+#if BC_DEBUG
 	bc_vec_free(&vm->jmp_bufs);
-#endif // NDEBUG
+#endif // BC_DEBUG
 
 	return s;
 }
