@@ -50,11 +50,12 @@ pll=1
 while getopts "n" opt; do
 
 	case "$opt" in
-		n) pll=0 ; shift ; set -e ;;
+		n) pll=0 ; set -e ;;
 		?) usage "Invalid option: $opt" ;;
 	esac
 
 done
+shift $(($OPTIND - 1))
 
 # Command-line processing.
 if [ "$#" -ge 1 ]; then
